==> 3.5.12-core.tar: kdepim/kontact/src/sidepanebase.h <==
/*
  This file is part of the KDE Kontact.

  Copyright (C) 2003 Cornelius Schumacher <schumacher@kde.org>

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; see the file COPYING.  If not, write to
  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  Boston, MA 02110-1301, USA.
*/
#ifndef KONTACT_SIDEPANEBASE_H
#define KONTACT_SIDEPANEBASE_H

#include <tqvbox.h>

namespace KParts { class Part; }

namespace Kontact
{

class Core;
class Plugin;

class SidePaneBase : public QVBox
{
    Q_OBJECT
  public:
    SidePaneBase( Core *core, TQWidget *parent, const char *name = 0 );
    virtual ~SidePaneBase();

  signals:
    void pluginSelected( Kontact::Plugin* );

  public slots:
    /**
      This method is called by the core whenever the count
      of plugins has changed.
     */
    virtual void updatePlugins() = 0;


    virtual void indicateForegrunding( Kontact::Plugin* ) = 0;
  protected:
    Core* core() const;

  private:
    Core* mCore;
    KActionCollection *mActionCollection;
};

}

#endif

==> 3.5.13-core.tar: kdepim/kontact/src/sidepanebase.h <==
/*
  This file is part of the KDE Kontact.

  Copyright (C) 2003 Cornelius Schumacher <schumacher@kde.org>

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; see the file COPYING.  If not, write to
  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  Boston, MA 02110-1301, USA.
*/
#ifndef KONTACT_SIDEPANEBASE_H
#define KONTACT_SIDEPANEBASE_H

#include <tqvbox.h>

namespace KParts { class Part; }

namespace Kontact
{

class Core;
class Plugin;

class SidePaneBase : public TQVBox
{
    Q_OBJECT
  TQ_OBJECT
  public:
    SidePaneBase( Core *core, TQWidget *parent, const char *name = 0 );
    virtual ~SidePaneBase();

  signals:
    void pluginSelected( Kontact::Plugin* );

  public slots:
    /**
      This method is called by the core whenever the count
      of plugins has changed.
     */
    virtual void updatePlugins() = 0;


    virtual void indicateForegrunding( Kontact::Plugin* ) = 0;
  protected:
    Core* core() const;

  private:
    Core* mCore;
    KActionCollection *mActionCollection;
};

}

#endif
